filter

package
v0.0.0-...-8d962dd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 15, 2023 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BlackFilter

func BlackFilter(c color.RGBA) color.RGBA

BlackFilter changes color c to color in black palette

func BlueFilter

func BlueFilter(c color.RGBA) color.RGBA

BlueFilter changes color c to color in blue palette

func BoxBlur

func BoxBlur(m *image.RGBA, r *image.Rectangle, k int) *image.RGBA

BoxBlur add box blur on image m in r bounds with kernel size k.

func DarkBlueFilter

func DarkBlueFilter(c color.RGBA) color.RGBA

DarkBlueFilter changes color c to color in blue palette

func Filter

func Filter(m *image.RGBA, r *image.Rectangle, f func(color.RGBA) color.RGBA) *image.RGBA

Filter add f filter function to every pixel on image m in r bounds.

func GreenFilter

func GreenFilter(c color.RGBA) color.RGBA

GreenFilter changes color c to color in green palette

func GreyFilter

func GreyFilter(c color.RGBA) color.RGBA

GreyFilter changes color c to color in grey palette

func OrangeFilter

func OrangeFilter(c color.RGBA) color.RGBA

OrangeFilter changes color c to color in orange palette

func PurpleFilter

func PurpleFilter(c color.RGBA) color.RGBA

PurpleFilter changes color c to color in purple palette

func RedFilter

func RedFilter(c color.RGBA) color.RGBA

RedFilter changes color c to color in red palette

func WhiteFilter

func WhiteFilter(c color.RGBA) color.RGBA

WhiteFilter changes color c to color in white palette

func YellowFilter

func YellowFilter(c color.RGBA) color.RGBA

YellowFilter changes color c to color in yellow palette

Types

This section is empty.

Jump to