Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Field ¶
type Field struct {
Seed int64
// contains filtered or unexported fields
}
Field where each point is a vector with values X,Y that is generated by noise function
func GenerateField ¶
GenerateField generates new field object and 2D noise based on given seed variable
func GenerateFieldFreq ¶
GenerateFieldFreq Generates new field object and 2D noise based on given seed and specified frequency variable
Click to show internal directories.
Click to hide internal directories.