Documentation
¶
Index ¶
- func BlackFilter(c color.RGBA) color.RGBA
- func BlueFilter(c color.RGBA) color.RGBA
- func BoxBlur(m *image.RGBA, r *image.Rectangle, k int) *image.RGBA
- func DarkBlueFilter(c color.RGBA) color.RGBA
- func Filter(m *image.RGBA, r *image.Rectangle, f func(color.RGBA) color.RGBA) *image.RGBA
- func GreenFilter(c color.RGBA) color.RGBA
- func GreyFilter(c color.RGBA) color.RGBA
- func OrangeFilter(c color.RGBA) color.RGBA
- func PurpleFilter(c color.RGBA) color.RGBA
- func RedFilter(c color.RGBA) color.RGBA
- func WhiteFilter(c color.RGBA) color.RGBA
- func YellowFilter(c color.RGBA) color.RGBA
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BlackFilter ¶
BlackFilter changes color c to color in black palette
func BlueFilter ¶
BlueFilter changes color c to color in blue palette
func DarkBlueFilter ¶
DarkBlueFilter changes color c to color in blue palette
func GreenFilter ¶
GreenFilter changes color c to color in green palette
func GreyFilter ¶
GreyFilter changes color c to color in grey palette
func OrangeFilter ¶
OrangeFilter changes color c to color in orange palette
func PurpleFilter ¶
PurpleFilter changes color c to color in purple palette
func WhiteFilter ¶
WhiteFilter changes color c to color in white palette
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.